Learn R Programming

asymLD (version 0.1)

snp.freqs: Pairwise haplotype frequencies for 4 SNP loci

Description

HLA haplotype frequencies for 6 pairs of SNP loci from the de Bakker et al. 2006 data for 90 unrelated individuals with European ancestry (CEU) from the Centre d'Etude du Polymorphisme Humain (CEPH) collection obtained from the Tagger/MHC webpage.

Usage

data(snp.freqs)

Arguments

Format

A data frame with 20 observations on the following 5 variables.
locus1
a character vector
locus2
a character vector
allele1
a character vector
allele2
a character vector
haplo.freq
a numeric vector

de Bakker, P. I., G. McVean, P. C. Sabeti, M. M. Miretti, T. Green et al., 2006 A high-resolution HLA and SNP haplotype map for disease association studies in the extended human MHC. Nat.Genet. 38: 1166-1172.

Details

For bi-allelic SNP data the ALD measures are symmetric and equivalent to the r correlation measure of LD.

References

http://www.broadinstitute.org/mpg/tagger/mhc.html