hla.freqs: Pairwise haplotype frequencies for 7 HLA loci
Description
HLA haplotype frequencies for 21 pairs of HLA loci in a set of 300 controls
from a study of myopericarditis incidence following smallpox vaccination.
Format
A data frame with 3063 observations on the following 5 variables.
haplo.freq- a numeric vector
locus1- a character vector
locus2- a character vector
allele1- a character vector
allele2- a character vector
Wilson, C., 2010 Identifying polymorphisms associated with risk for the development of myopericarditis following smallpox vaccine. The Immunology Database and Analysis Portal (ImmPort), Study #26.References
https://immport.niaid.nih.gov/immportWeb/clinical/study/displayStudyDetails.do?itemList=SDY26